'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var constants = require('../../shared/constants.js');
var utils = require('./utils.js');

/**
 * We have to keep the cookie value in sync as Next.js might
 * skip a request to the server due to its router cache.
 * See https://github.com/amannn/next-intl/issues/786.
 */
function syncLocaleCookie(pathname, locale, nextLocale) {
  const isSwitchingLocale = nextLocale !== locale && nextLocale != null;
  if (!isSwitchingLocale ||
  // Theoretical case, we always have a pathname in a real app,
  // only not when running e.g. in a simulated test environment
  !pathname) {
    return;
  }
  const basePath = utils.getBasePath(pathname);
  const hasBasePath = basePath !== '';
  const path = hasBasePath ? basePath : '/';

  // Note that writing to `document.cookie` doesn't overwrite all
  // cookies, but only the ones referenced via the name here.
  document.cookie = "".concat(constants.COOKIE_LOCALE_NAME, "=").concat(nextLocale, "; path=").concat(path, "; max-age=").concat(constants.COOKIE_MAX_AGE, "; sameSite=").concat(constants.COOKIE_SAME_SITE);
}

exports.default = syncLocaleCookie;
